This module provides models that are used in the openlimits-binance module
Modules
- shared
- This module cointains some auxiliar functions that are used in the openlimits-exchange module
- websocket
- Websocket model
Structs
- Account
Information - This struct represents the informations about the account
- AllOrder
Req - This struct represents all order
- AskBid
- This struct represents ask and bid
- Balance
- This struct represent the balance
- Exchange
Information - This struct represents informations about the openlimits-exchange
- Kline
- Kline
Params - Kline
Summary - Market
Pair - Order
- This struct represents an order
- Order
Book - This struct represents a order book
- Order
Canceled - This struct represents a cancel order
- Order
Request - This struct represents an order request
- Paginator
- This struct represents a paginator
- Price
Stats - This struct represents price statistics
- Rate
Limit - This struct represents the rate limit
- Server
Time - This struct represents the server time
- Success
- Symbol
- Symbol
Price - This struct represents the symbol price
- Ticker
- This struct represents a ticker
- Trade
History - This struct represents a trade history
- Trade
History Req - This struct represents a trade history request
- Transaction
- This struct represents a transaction
- User
Data Stream
Enums
- Book
Tickers - This enum represents a book ticker
- Exchange
Filter - This enum represents an openlimits-exchange filter
- Interval
- This enum represents a time interval
- Kline
Summaries - Order
Exec Type - This enum represents the type of executed order
- Order
Reject Reason - This enum represents the reason why an order was rejected
- Order
Status - This enum represents an order status
- Order
Type - Oder types
- Prices
- This enum represents the prices
- Rate
Limit Type - This enum represents the type of rate limit
- Side
- This struct represent the buy-side and sell-side
- Symbol
Filter - Time
InForce - This struct represents time in force