pub struct BinanceParameters {
pub environment: Environment,
pub credentials: Option<BinanceCredentials>,
}Expand description
This struct represents the type of environment that will be used and receives a boolean and the credentials as parameters.
Fields
environment: Environmentcredentials: Option<BinanceCredentials>Implementations
Sourceimpl BinanceParameters
impl BinanceParameters
Sourcepub fn production() -> Self
pub fn production() -> Self
Production environment