This module is used to make calls to api and connect to the websockets
Modules
- shared
- This module cointains some auxiliar functions that are used in the openlimits-exchange module
- stream
Structs
- Base
Client - The openlimits-binance client