Module model

Module model 

This module provides models that are used in the openlimits-binance module

Modules

shared
This module cointains some auxiliar functions that are used in the openlimits-exchange module
websocket
Websocket model

Structs

AccountInformation
This struct represents the informations about the account
AllOrderReq
This struct represents all order
AskBid
This struct represents ask and bid
Balance
This struct represent the balance
ExchangeInformation
This struct represents informations about the openlimits-exchange
Kline
KlineParams
KlineSummary
MarketPair
Order
This struct represents an order
OrderBook
This struct represents a order book
OrderCanceled
This struct represents a cancel order
OrderRequest
This struct represents an order request
Paginator
This struct represents a paginator
PriceStats
This struct represents price statistics
RateLimit
This struct represents the rate limit
ServerTime
This struct represents the server time
Success
Symbol
SymbolPrice
This struct represents the symbol price
Ticker
This struct represents a ticker
TradeHistory
This struct represents a trade history
TradeHistoryReq
This struct represents a trade history request
Transaction
This struct represents a transaction
UserDataStream

Enums

BookTickers
This enum represents a book ticker
ExchangeFilter
This enum represents an openlimits-exchange filter
Interval
This enum represents a time interval
KlineSummaries
OrderExecType
This enum represents the type of executed order
OrderRejectReason
This enum represents the reason why an order was rejected
OrderStatus
This enum represents an order status
OrderType
Oder types
Prices
This enum represents the prices
RateLimitType
This enum represents the type of rate limit
Side
This struct represent the buy-side and sell-side
SymbolFilter
TimeInForce
This struct represents time in force

Constants

ORDER_SIDE_BUY
ORDER_SIDE_SELL
ORDER_TYPE_LIMIT
ORDER_TYPE_LIMIT_MAKER
ORDER_TYPE_MARKET
TIME_IN_FORCE_GTC